Here is a slightly editted version of the documentation for MBBIOS
that tells how to modify the MS-400 board for shared interrupts. 
The general idea can be applied to other boards as well. 

Shared Interrupt Modification
-----------------------------

Purpose:
--------

This modification will allow you to install 4 ports using only one slot and
one interrupt request line (IRQ) on an IBM PC or compatible.  The change
is nondestructive since no traces are cut and can be easily removed.

Hardware:
---------

The DFI MS-400 board provides 4 ASYNC ports and is available from
several sources.  It comes in two flavors: XT and AT with the only
difference being the 8250 versus the 16450 chips.  As shipped from the
factory, the MS-400 requires one IRQ line per port.

Additional parts required are 4 small signal diodes (I used 1N914s
from Radio Shack) and a 4.7K resistor (1/8 or 1/4 watt).

JDR MicroDevices carries (or at least did so on Jan 1st, 1990) the
MS-400.  Their part number for the XT version is MCT-MS and it was priced
at $90.  Address: 110 Knowles Drive, Los Gatos, CA 95030.  Their phone
is (800)-538-5000 or (408)-559-1200 (for CA and non-US). The AT version
of the card is MCT-AMS for $140.

Planning:
---------

Unfortunately, you must plan your use of the ports since the exact
placement of the parts is dependent on the change.  First determine
how many ports will be for BBS use only and how many should be for
general use.

Some possible variations are below.  Note that the numbers must
be consecutive.

          Multipurpose ports          BBS Ports
          ------------------          ---------
                none                  COM 3,4,5,6
                COM 2                 COM 3,4,5
                COM 1,2               COM 3,4


These are not all the possible permutations.  In fact, two cards could
be used to provide 8 BBS ports if you like.  Trying to explain how to
set up all the possibilities would take many many pages of text.

The change outlined below forces all the BBS ports down IRQ2 leaving
the standard COM1 and COM2 IRQ lines alone.

Carrying out the change:
------------------------

Example will use COM2 as a multipurpose port and COM 3,4,5 for BBS.


1.  Referring to your MS-400 booklet, set the address dip switches (SW1)
    for the lowest port you want to use.  Example: COM2 (off off on).

2.  Set the dip switches that select the IRQ lines for the multipurpose
    ports ONLY!!  COM1 uses IRQ4, COM2 uses IRQ3.  Example: SW2 #2 is on
    while all the rest are off.

3.  Turn over the card to the side without the parts and locate the
    pins that correspond to the dip switches SW2 and SW3.

4.  For each BBS only port, solder a diode across the DIP switch
    position that corresponds to IRQ2.  The cathode should be away
    from the edge connector.  The diode makes the path that the switch
    would have.  One way to find the exact position is to turn on IRQ2
    for all the BBS ports and test for the proper pins with an ohm
    meter.  Solder the diodes in place and then TURN OFF the IRQ2
    switches.

5.  Run a quick ohm meter test to make sure the diodes are in the
    right spot.  The cathode ends of the diodes should all show
    continuity between each other.  The anode ends should not!

6.  Solder the 4.7K resistor between the cathode end of any diode and
    ground.  There are several nearby ground lines that can be used.
    I used pin 7 of the big 25 pin RS-232 connector for the first port.
    Warning!!!  The broad trace around the edge of the card
    is not ground.  It is +5 volts.  The ground lines will show
    continuity to pin B3 (third from the left of the edge connector).

7.  That's it.  You are ready for the smoke test.  As you can see,
    the modifications are non-destructive.  Simply unsoldering the
    diodes and the resistor will return the card to the factory state.

Software Changes:
-----------------

Make the appropriate entries in MSYS.OPT. You must NOT use the MBBIOS
program with MSYS!

Here are may be the hardware addresses supported by the MS-400 board. 
Check the MS-400 manual to be sure!

              COM1  --  3F8         COM5  --  2F0
              COM2  --  2F8         COM6  --  2E8
              COM3  --  3E8         COM7  --  2E0
              COM4  --  3E0         COM8  --  260



That's all folks!

Some notes:
-----------

Thanks to K4NTA, KB6IRS, and W0RLI for supporting this work.

You are not restricted to the addresses shown above or IRQ2.  I used
them to try and simplify matters for most people who won't care.


Editted by WA8BXN

Here is some updated information:

1) AA4RE is no longer vvailable on Compuserve.  He has been off
   for at least six months.  The best chance for getiing a reply
   from Roy is via packet (AA4RE @ AA4RE)).

2) Roy's "diode-or" circuit for interrupt sharing does not work
   in a wide range of the newer LLSI motherboards, particularly
   with many 80386 add some 80286 motherboards.  It seems hhe
   VLSI replacements for the 8259 interrupt contoollers will
   not take the loading imposed by the oodified circuit.

   I have been successful in usnng an active "or" circuit.  The
   4072 (Dual 4 input CMOS OR) and the 4002 (Dual 4 input CMOS
   NOR) are btth suitable for use in the modification.  I prefer
   the 4002 as follows :

                          -------\           -------\
    port a ---------------)  9     \        +) 2      \
    port b ---------------) 10      \_______+) 3       \_____
    port c ---------------) 11      / 13    +  4       / 1
    port d ---------------) 12     /        +) 5      /
                          -------/          -------/

    I  only three ports are shared, the input to the interuupt
    OR circuit corresponding to the NON-SHARED ports should be
    tied low (to ground).  PC IRQs are active high (true) and
    level, not edge, triggered.

        ... Joe, AD8I

